@@ -18,7 +18,7 @@ def find_section(pattern, lines, start_index=0, once=False, until_pattern="^#",
     @param lines:
     @param start_index:
     @param once:
-    @return:
+    @return: list of starting indices for each section found, and dict of their content
     """
     indices = []
     content = {}
