@@ -338,7 +338,7 @@ class TestcaseService:
                 os.chdir(owd)
                 return
             # C:\\Program Files\\CodeBlocks\\MinGW\\bin\\g++
-            compile_cmd = ["g++.exe", "-std=c++14",
+            compile_cmd = ["g++", "-std=c++14",
                            file_name,
                            "-pipe", f"-o{file_base_name}.exe"]
             ShellHelper.execute(compile_cmd, timeout=timeout)
