@@ -567,16 +567,16 @@ def create_problems_to_lesson_ucode(env="dev", domain="ucode.vn"):
     # base_folder = r"D:\projects\ucode\weekly-algorithm-problems\competitions\teko-hcm"
     # base_folder = r"D:\projects\freecontest\mock_tests\mock01"
     # base_folder = r"D:\projects\ucode\competitive_programing_topics\tests\sample_tests\thcs_testTHT"
-    # base_folder = r"D:\projects\ucode\dsa-problem-bank\tests_lamcherry (9-2021)\thcs_tests\test_02"
+    base_folder = r"D:\projects\ucode\dsa-problem-bank\lamcherry\2021-09\thcs_tests\test_02"
 
     # base_folder = "D:\\projects\\ucode\\competitive_programing_topics\\Data_Structures\\Heap_PriorityQueue"
-    # problems = ProblemService.read_all_problems(base_folder, nested_folder=False)
+    problems = ProblemService.read_all_problems(base_folder, nested_folder=False)
     # problems = ProblemService.read_all_problems_v1(base_folder, nested_folder=False)
 
-    prob_folder = r"D:\projects\ucode\dsa-problem-bank\lamcherry\2021-09\thpt_tests\test_05\p04_bookshelves"
-    problems = [(prob_folder, ProblemService.load(prob_folder))]
+    # prob_folder = r"D:\projects\ucode\dsa-problem-bank\lamcherry\2021-09\thpt_tests\test_05\p04_bookshelves"
+    # problems = [(prob_folder, ProblemService.load(prob_folder))]
 
-    lesson_id = 22910
+    lesson_id = 23465
     ucode = UCode(env=env, domain=domain)
     #
 
@@ -584,14 +584,14 @@ def create_problems_to_lesson_ucode(env="dev", domain="ucode.vn"):
         problem = ProblemService.load(problem_folder, load_testcase=True)
         # problem = ProblemService.load_v1(problem_folder, load_testcase=True, translations=['vi'])
         print(i + 1, problem.name, "testcases:", len(problem.testcases), ", sample test:", len(problem.testcases_sample))
-        print("Solution:", json.dumps(problem.solutions))
-        print("Editorial:", problem.editorial)
-        print("Constraint: ", problem.constraints)
+        # print("Solution:", json.dumps(problem.solutions))
+        # print("Editorial:", problem.editorial)
+        # print("Constraint: ", problem.constraints)
 
         prob_id = ucode.create_problem(problem=problem, xp=-1, score=100)
         CLog.info(f"Created problem: {prob_id}")
-        # ucode.add_question_to_quiz(quiz_id=lesson_id, question_ids=[prob_id])
-        # print(f"Problem uploaded with id #{prob_id} and added to quiz {lesson_id}")
+        ucode.add_question_to_quiz(quiz_id=lesson_id, question_ids=[prob_id])
+        print(f"Problem uploaded with id #{prob_id} and added to quiz {lesson_id}")
 
     print("Total problems:", len(problems))
 
@@ -721,7 +721,7 @@ UX/UI	12/11/2020	BB #19: How to use Teko Design System for PO an BA	Trần Thàn
 
 
 if __name__ == "__main__":
-    # test_login()
+    test_login()
     # teko_bb()
     # reupload_testcases()
 
